web

Function web 

pub fn web(root: impl AsRef<Path>, options: WebOptions) -> Result<()>
Start a local-only project analysis and transition to the existing review UI. Generated reports and restore backups are retained after the process exits.