pub struct ResourceAnalysis {
pub resource: Resource,
pub sha256: Option<String>,
pub image: Option<ImageInfo>,
pub status: String,
pub issues: Vec<String>,
pub candidates: Vec<ImageCandidate>,
pub smallest_candidate: Option<usize>,
pub original_preview: Option<PathBuf>,
pub original_artifact: Option<PathBuf>,
pub media: Option<MediaInfo>,
pub fingerprint: Option<Fingerprint>,
}Fields
resource: Resourcesha256: Option<String>image: Option<ImageInfo>status: Stringcandidates_available, inspected, excluded, unsupported, failed
or not_analyzed (analysis was cancelled first).
issues: Vec<String>candidates: Vec<ImageCandidate>smallest_candidate: Option<usize>A size winner among candidates that passed every policy check.
original_preview: Option<PathBuf>original_artifact: Option<PathBuf>media: Option<MediaInfo>Codec, duration and bitrate of audio/video files, when ffprobe is installed.
fingerprint: Option<Fingerprint>Scale-invariant fingerprint used to find duplicate and resized images.